import { _ActionTypeId, _UnmarshalledActionTypeId } from "./_ActionTypeId";
import { _ActionConfiguration, _UnmarshalledActionConfiguration } from "./_ActionConfiguration";
import { _PipelineContext, _UnmarshalledPipelineContext } from "./_PipelineContext";
import { _Artifact, _UnmarshalledArtifact } from "./_Artifact";
import { _AWSSessionCredentials, _UnmarshalledAWSSessionCredentials } from "./_AWSSessionCredentials";
import { _EncryptionKey, _UnmarshalledEncryptionKey } from "./_EncryptionKey";
/**
 * <p>Represents information about the job data for a partner action.</p>
 */
export interface _ThirdPartyJobData {
    /**
     * <p>Represents information about an action type.</p>
     */
    actionTypeId?: _ActionTypeId;
    /**
     * <p>Represents information about an action configuration.</p>
     */
    actionConfiguration?: _ActionConfiguration;
    /**
     * <p>Represents information about a pipeline to a job worker.</p> <note> <p>Does not include <code>pipelineArn</code> and <code>pipelineExecutionId</code> for ThirdParty jobs.</p> </note>
     */
    pipelineContext?: _PipelineContext;
    /**
     * <p>The name of the artifact that will be worked upon by the action, if any. This name might be system-generated, such as "MyApp", or might be defined by the user when the action is created. The input artifact name must match the name of an output artifact generated by an action in an earlier action or stage of the pipeline.</p>
     */
    inputArtifacts?: Array<_Artifact> | Iterable<_Artifact>;
    /**
     * <p>The name of the artifact that will be the result of the action, if any. This name might be system-generated, such as "MyBuiltApp", or might be defined by the user when the action is created.</p>
     */
    outputArtifacts?: Array<_Artifact> | Iterable<_Artifact>;
    /**
     * <p>Represents an AWS session credentials object. These credentials are temporary credentials that are issued by AWS Secure Token Service (STS). They can be used to access input and output artifacts in the Amazon S3 bucket used to store artifact for the pipeline in AWS CodePipeline. </p>
     */
    artifactCredentials?: _AWSSessionCredentials;
    /**
     * <p>A system-generated token, such as a AWS CodeDeploy deployment ID, that a job requires in order to continue the job asynchronously.</p>
     */
    continuationToken?: string;
    /**
     * <p>The encryption key used to encrypt and decrypt data in the artifact store for the pipeline, such as an AWS Key Management Service (AWS KMS) key. This is optional and might not be present.</p>
     */
    encryptionKey?: _EncryptionKey;
}
export interface _UnmarshalledThirdPartyJobData extends _ThirdPartyJobData {
    /**
     * <p>Represents information about an action type.</p>
     */
    actionTypeId?: _UnmarshalledActionTypeId;
    /**
     * <p>Represents information about an action configuration.</p>
     */
    actionConfiguration?: _UnmarshalledActionConfiguration;
    /**
     * <p>Represents information about a pipeline to a job worker.</p> <note> <p>Does not include <code>pipelineArn</code> and <code>pipelineExecutionId</code> for ThirdParty jobs.</p> </note>
     */
    pipelineContext?: _UnmarshalledPipelineContext;
    /**
     * <p>The name of the artifact that will be worked upon by the action, if any. This name might be system-generated, such as "MyApp", or might be defined by the user when the action is created. The input artifact name must match the name of an output artifact generated by an action in an earlier action or stage of the pipeline.</p>
     */
    inputArtifacts?: Array<_UnmarshalledArtifact>;
    /**
     * <p>The name of the artifact that will be the result of the action, if any. This name might be system-generated, such as "MyBuiltApp", or might be defined by the user when the action is created.</p>
     */
    outputArtifacts?: Array<_UnmarshalledArtifact>;
    /**
     * <p>Represents an AWS session credentials object. These credentials are temporary credentials that are issued by AWS Secure Token Service (STS). They can be used to access input and output artifacts in the Amazon S3 bucket used to store artifact for the pipeline in AWS CodePipeline. </p>
     */
    artifactCredentials?: _UnmarshalledAWSSessionCredentials;
    /**
     * <p>The encryption key used to encrypt and decrypt data in the artifact store for the pipeline, such as an AWS Key Management Service (AWS KMS) key. This is optional and might not be present.</p>
     */
    encryptionKey?: _UnmarshalledEncryptionKey;
}
